==> sigil_1.1.0%2Bdfsg.orig.tar.xz: Sigil-1.1.0/src/Tabs/AVTab.cpp <==
/************************************************************************
**
**  Copyright (C) 2019-2020 Kevin B. Hendricks, Stratford, Ontario Canada
**  Copyright (C) 2012      John Schember <john@nachtimwald.com>
**
**  This file is part of Sigil.
**
**  Sigil is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  Sigil is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Sigil.  If not, see <http://www.gnu.org/licenses/>.
**
*************************************************************************/

#include <QtCore/QString>
#include <QtCore/QUrl>
#include <QtWidgets/QLayout>
#include <QtWebEngineWidgets/QWebEngineProfile>
#include <QtWebEngineWidgets/QWebEngineView>
#include <QGuiApplication>
#include <QApplication>
#include "MainUI/MainWindow.h"
#include "ViewEditors/SimplePage.h"
#include "Misc/Utility.h"
#include "sigil_constants.h"

#include "Tabs/AVTab.h"

const QString AUDIO_HTML_BASE =
    "<html>"
    "<head>"
    "<style type=\"text/css\">"
    "body { -webkit-user-select: none; }"
    "audio { display: block; margin-left: auto; margin-right: auto; }"
    "</style>"
    "</head>"
    "<body>"
    "<p><audio controls=\"controls\" src=\"%1\"></audio></p>"
    "</body>"
    "</html>";

const QString VIDEO_HTML_BASE =
    "<html>"
    "<head>"
    "<style type=\"text/css\">"
    "body { -webkit-user-select: none; }"
    "video { display: block; margin-left: auto; margin-right: auto; }"
    "</style>"
    "</head>"
    "<body>"
    "<p><video controls=\"controls\" width=\"560\" src=\"%1\"></video></p>"
    "</body>"
    "</html>";

AVTab::AVTab(Resource *resource, QWidget *parent)
    : ContentTab(resource, parent),
      m_WebView(new QWebEngineView(this))
{
    m_WebView->setPage(new SimplePage(m_WebView));
    m_WebView->setContextMenuPolicy(Qt::NoContextMenu);
    m_WebView->setFocusPolicy(Qt::NoFocus);
    m_WebView->setAcceptDrops(false);
    m_Layout->addWidget(m_WebView);
    ConnectSignalsToSlots();
    RefreshContent();
}

void AVTab::RefreshContent()
{
    m_WebView->page()->profile()->clearHttpCache();
    QString html;
    const QString path = m_Resource->GetFullPath();
    const QUrl resourceUrl = QUrl::fromLocalFile(path);
    if (m_Resource->Type() == Resource::AudioResourceType) {
        html = AUDIO_HTML_BASE.arg(resourceUrl.toString());
    } else {
        html = VIDEO_HTML_BASE.arg(resourceUrl.toString());
    }
    if (Utility::IsDarkMode()) {
        html = Utility::AddDarkCSS(html);
    }
    m_WebView->page()->setBackgroundColor(Utility::WebViewBackgroundColor());
    m_WebView->setHtml(html, resourceUrl);
}

void AVTab::ConnectSignalsToSlots()
{
    connect(m_Resource, SIGNAL(ResourceUpdatedOnDisk()), this, SLOT(RefreshContent()));
    connect(m_Resource, SIGNAL(Deleted(Resource)), this, SLOT(Close()));
}

==> sigil_1.9.2%2Bdfsg.orig.tar.xz: Sigil-1.9.2/src/Tabs/AVTab.cpp <==
/************************************************************************
**
**  Copyright (C) 2019-2020 Kevin B. Hendricks, Stratford, Ontario Canada
**  Copyright (C) 2012      John Schember <john@nachtimwald.com>
**
**  This file is part of Sigil.
**
**  Sigil is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  Sigil is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Sigil.  If not, see <http://www.gnu.org/licenses/>.
**
*************************************************************************/

#include <QtCore/QString>
#include <QtCore/QUrl>
#include <QtWidgets/QLayout>
#include <QGuiApplication>
#include <QApplication>
#include "MainUI/MainWindow.h"
#include "Misc/Utility.h"
#include "sigil_constants.h"
#include "Widgets/AVView.h"
#include "Tabs/AVTab.h"

AVTab::AVTab(Resource *resource, QWidget *parent)
    : ContentTab(resource, parent),
      m_av(new AVView(this))
{
    m_Layout->addWidget(m_av);
    ConnectSignalsToSlots();
    ShowAV();
}

void AVTab::ShowAV()
{
    m_av->ShowAV(m_Resource->GetFullPath());
}

void AVTab::RefreshContent()
{
    m_av->ReloadViewer();
}

void AVTab::ConnectSignalsToSlots()
{
    connect(m_Resource, SIGNAL(ResourceUpdatedOnDisk()), this, SLOT(RefreshContent()));
    connect(m_Resource, SIGNAL(Deleted(const Resource*)), this, SLOT(Close()));
}
